@@ -1,4 +1,5 @@
 test_that("Load Session (file cached) Works", {
+  testthat::skip_if_offline("livetiming.formula1.com")
   skip_if_no_py()
   skip_if_no_ff1()
 
@@ -18,19 +19,19 @@ test_that("Load Session (file cached) Works", {
   ff1_ver <- get_fastf1_version()
   if (ff1_ver < "3.1") {
     expect_error(
-      session <- load_race_session(season = 2022, round = 1),
+      session <- load_race_session(season = 2023, round = 1),
       "An old version of FastF1 is in use"
     )
     skip("Skipping load_race_session as FastF1 is out of date.")
   }
 
   # test with all parameters but session provided
-  expect_invisible(load_race_session(season = 2022, round = 1))
+  expect_invisible(load_race_session(season = 2023, round = 1))
   # validate the cache is there now
   expect_true(file.exists(file.path(tempdir(), "tst_session", "fastf1_http_cache.sqlite")))
 
   # test without race provided - loads from cache
-  expect_invisible(load_race_session(season = 2022, session = "R"))
+  expect_invisible(load_race_session(season = 2023, session = "R"))
 
   # test without season provided - default is current year assigned at argument
   session1 <- load_race_session(session = "R")
@@ -39,10 +40,10 @@ test_that("Load Session (file cached) Works", {
   expect_equal(session1$api_path, session2$api_path)
 
   # verify character and numeric race can draw the same endpoint
-  session1 <- load_race_session(season = 2022, round = 1, session = "R")
-  session2 <- load_race_session(season = 2022, round = "Bahrain", session = "R")
+  session1 <- load_race_session(season = 2023, round = 1, session = "R")
+  session2 <- load_race_session(season = 2023, round = "Bahrain", session = "R")
   expect_equal(session1$api_path, session2$api_path)
-  expect_equal(session1$event$OfficialEventName, "FORMULA 1 GULF AIR BAHRAIN GRAND PRIX 2022")
+  expect_equal(session1$event$OfficialEventName, "FORMULA 1 GULF AIR BAHRAIN GRAND PRIX 2023")
 
   expect_error(
     load_race_session(season = 2017),
@@ -52,12 +53,14 @@ test_that("Load Session (file cached) Works", {
     load_race_session(session = "ZZZ"),
     '`session` must be one of "FP1", "FP2", "FP3", "Q", "SQ", "SS", "S", or "R"'
   )
-  expect_error(load_race_session(season = 2022, round = 1, session = "R", log_level = "ZZZ"))
+  expect_error(load_race_session(season = 2023, round = 1, session = "R", log_level = "ZZZ"))
 
-  expect_error(load_race_session(season = 2022, race = "Bahrain", session = "R"))
+  expect_error(load_race_session(season = 2023, race = "Bahrain", session = "R"))
+
+  expect_error(load_race_session(season = 2023, round = 100, session = "R"))
 
   expect_message(
-    load_race_session(season = 2022, round = 1, session = "R", log_level = "INFO"),
+    load_race_session(season = 2023, round = 1, session = "R", log_level = "INFO"),
     "The first time a session is loaded, some time is required. Please*"
   )
 })
@@ -77,14 +80,14 @@ test_that("Load Session (memory cached) Works", {
   ff1_ver <- get_fastf1_version()
   if (ff1_ver < "3.1") {
     expect_error(
-      session <- load_race_session(season = 2022, round = 1),
+      session <- load_race_session(season = 2023, round = 1),
       "An old version of FastF1 is in use"
     )
     skip("Skipping load_race_session (memory cache) test as FastF1 is out of date.")
   }
 
-  session1 <- load_race_session(season = 2022, round = 1, session = "R")
-  expect_equal(session1$event$OfficialEventName, "FORMULA 1 GULF AIR BAHRAIN GRAND PRIX 2022")
+  session1 <- load_race_session(season = 2023, round = 1, session = "R")
+  expect_equal(session1$event$OfficialEventName, "FORMULA 1 GULF AIR BAHRAIN GRAND PRIX 2023")
 })
 
 test_that("Load Session works without internet", {
@@ -114,8 +117,8 @@ test_that("Load Session works without internet", {
     suppressWarnings({
       suppressMessages({
         httptest2::without_internet({
-          expect_message(load_race_session(season = 2022, round = 1), "f1dataR: Can't connect to F1 Live Timing for FastF1 data download")
-          expect_null(load_race_session(season = 2022, round = 1))
+          expect_message(load_race_session(season = 2023, round = 1), "f1dataR: Can't connect to F1 Live Timing for FastF1 data download")
+          expect_null(load_race_session(season = 2023, round = 1))
         })
       })
     })
